package cn.com.infosec.asn1.pkcs;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DERNull;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DEROctetString;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.oiw.OIWObjectIdentifiers;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;

public class RSAESOAEPparams extends ASN1Encodable {
   public static final AlgorithmIdentifier DEFAULT_HASH_ALGORITHM;
   public static final AlgorithmIdentifier DEFAULT_MASK_GEN_FUNCTION;
   public static final AlgorithmIdentifier DEFAULT_P_SOURCE_ALGORITHM;
   private AlgorithmIdentifier hashAlgorithm;
   private AlgorithmIdentifier maskGenAlgorithm;
   private AlgorithmIdentifier pSourceAlgorithm;

   static {
      AlgorithmIdentifier var0;
      AlgorithmIdentifier var10000 = var0 = new AlgorithmIdentifier;
      var10000.<init>(OIWObjectIdentifiers.idSHA1, new DERNull());
      DEFAULT_HASH_ALGORITHM = var10000;
      DEFAULT_MASK_GEN_FUNCTION = new AlgorithmIdentifier(PKCSObjectIdentifiers.id_mgf1, var0);
      DEFAULT_P_SOURCE_ALGORITHM = new AlgorithmIdentifier(PKCSObjectIdentifiers.id_pSpecified, new DEROctetString(new byte[0]));
   }

   public static RSAESOAEPparams getInstance(Object obj) {
      if (obj instanceof RSAESOAEPparams) {
         return (RSAESOAEPparams)obj;
      } else if (obj instanceof ASN1Sequence) {
         return new RSAESOAEPparams((ASN1Sequence)obj);
      } else {
         throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
      }
   }

   public RSAESOAEPparams() {
      this.hashAlgorithm = DEFAULT_HASH_ALGORITHM;
      this.maskGenAlgorithm = DEFAULT_MASK_GEN_FUNCTION;
      this.pSourceAlgorithm = DEFAULT_P_SOURCE_ALGORITHM;
   }

   public RSAESOAEPparams(AlgorithmIdentifier hashAlgorithm, AlgorithmIdentifier maskGenAlgorithm, AlgorithmIdentifier pSourceAlgorithm) {
      this.hashAlgorithm = hashAlgorithm;
      this.maskGenAlgorithm = maskGenAlgorithm;
      this.pSourceAlgorithm = pSourceAlgorithm;
   }

   public RSAESOAEPparams(ASN1Sequence seq) {
      this.hashAlgorithm = DEFAULT_HASH_ALGORITHM;
      this.maskGenAlgorithm = DEFAULT_MASK_GEN_FUNCTION;
      this.pSourceAlgorithm = DEFAULT_P_SOURCE_ALGORITHM;

      for(int var2 = 0; var2 != seq.size(); ++var2) {
         ASN1TaggedObject var3;
         int var4;
         if ((var4 = (var3 = (ASN1TaggedObject)seq.getObjectAt(var2)).getTagNo()) != 0) {
            if (var4 != 1) {
               if (var4 != 2) {
                  throw new IllegalArgumentException("unknown tag");
               }

               this.pSourceAlgorithm = AlgorithmIdentifier.getInstance(var3, true);
            } else {
               this.maskGenAlgorithm = AlgorithmIdentifier.getInstance(var3, true);
            }
         } else {
            this.hashAlgorithm = AlgorithmIdentifier.getInstance(var3, true);
         }
      }

   }

   public AlgorithmIdentifier getHashAlgorithm() {
      return this.hashAlgorithm;
   }

   public AlgorithmIdentifier getMaskGenAlgorithm() {
      return this.maskGenAlgorithm;
   }

   public AlgorithmIdentifier getPSourceAlgorithm() {
      return this.pSourceAlgorithm;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      var1 = new ASN1EncodableVector.<init>();
      DERTaggedObject var10001;
      DERTaggedObject var2;
      AlgorithmIdentifier var3;
      if (!this.hashAlgorithm.equals(DEFAULT_HASH_ALGORITHM)) {
         var10001 = var2 = new DERTaggedObject;
         var3 = this.hashAlgorithm;
         var10001.<init>(true, 0, var3);
         var1.add(var2);
      }

      if (!this.maskGenAlgorithm.equals(DEFAULT_MASK_GEN_FUNCTION)) {
         var10001 = var2 = new DERTaggedObject;
         var3 = this.maskGenAlgorithm;
         var10001.<init>(true, 1, var3);
         var1.add(var2);
      }

      if (!this.pSourceAlgorithm.equals(DEFAULT_P_SOURCE_ALGORITHM)) {
         var10001 = var2 = new DERTaggedObject;
         AlgorithmIdentifier var4 = this.pSourceAlgorithm;
         var10001.<init>(true, 2, var4);
         var1.add(var2);
      }

      return new DERSequence(var1);
   }
}
